<?php
namespace WSCOMUN\GDE;
use WSCOMUN\WSComunFClient;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de GD2
 *
 * @package		WSClientGDE2
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientGDE2 extends WSComunFClient
{

	/**
	 * Constantes para URL de consultas al frontend
	 */

	const URL_FRONT_DESARROLLO = 'https://previs.gva.es/gde-front/';
	const URL_FRONT_PRODUCCION = 'https://www.tramita.gva.es/gde-front/';


	/**
	 * Inserta doc segn parmetros recibidos y devuelve referencia al mismo
	 *
	 * No se requerir especificar las firmas, los metadatos del ENI o los
	 * metadatos personalizados. Esto permitir el uso por parte de aplicaciones
	 * que no requieran de intercambio de documentos ENI. Si se especifican
	 * metadatosEni y el Identificador ENI no viene informado, se generar
	 * automticamente por parte del GDE. Si no se indica el path se almacenar
	 * de forma automtica. En caso de que se indique path se establecer en
	 * el path indicado.
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$docContentB64	Contenido del documento en Base64
	 * @param  	string	$nombreDoc	Nombre Doc.
	 * @param  	string	$pathDoc	Path relativo al espacio raz de la app
	 * @param  	array	$vMetadatosENI	Opcional. Array asociativo con meta informacin ENI [versionNTI|identificador|tipoDocumental|nombreFormatoorgano|fechaCaptura|estadoElaboracion|origenCiudadanoAdministracion|identificadorDocumentoOrigen]
	 * @param  	array	$vMetadatosPersonalizados	Opcional. Array asociativo. [idColeccionMetadatosPersonalizados|metadatosPersonalizados]
	 * @return	array 	$vFirmas Opcional. Array asociativo. Firmas
	 * @access 	public
	 */
	public function insertarDocumento($codApp, $docContentB64, $nombreDoc, $pathDoc=null, $tipo = null, $vMetadatosENI = null, $vMetadatosPersonalizados=null, $vFirmas=null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_GDE2, true);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_GDE2];

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__insertarDocumento_full(
					array(
							'contenido' => $docContentB64,
							'nombre' => $nombreDoc,
							'path' => $pathDoc,
							'tipoPersonalizado' => $tipo,
							'metadatosENI' => $vMetadatosENI,
							'coleccionMetadatosPersonalizados' => $vMetadatosPersonalizados,
							'firmas' => $vFirmas
					), 'peticion', self::$NAMESPACE_GDE2);

			$insertarDocumentoWSRequest = new \ArrayObject();
			$insertarDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$insertarDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($insertarDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'insertarDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->insertarDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//insertarDocumento



	/**
	 * [ORQUESTA] Accede al doc y devuelva la informacin asocaida al msimo
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia Alfresco del Doc
	 * @param  	string	$parcial Indica que datos recuprar (1: Todo, 2: Contenido, 3: MEtadatos, 4: Metadatos y Firmas)
	 * @return	array	Array asociativo [contenido|nombre|borrado|metadatosENI|metadatosPersonalizados|firmas]
	 * @access 	public
	 */
	public function obtenerDocumento($codApp, $refDoc, $parcial='1')
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__obtenerDocumento_full(
					array(
							'referenciaDocumento' => $refDoc ,
							'parcial'			  => $parcial
					), 'peticion', self::$NAMESPACE_GDE2);

			$obtenerDocumentoWSRequest = new \ArrayObject();
			$obtenerDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$obtenerDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'obtenerDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					// Realiza la interpretacion/sustitucion estandar de MTOM
					$vRetorno = $this->tratarMTOMEstandar($response);
					return ($vRetorno);

				case 'gde_documentonoexistenteexception':
					return array(
					'respuesta'		=>	array('correcto'=>'false'),
					'codMotivo'		=> 'NOEXISTE',
					'motivo'		=> 'No existe ningn documento con la referencia '.$refDoc
					);
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//obtenerDocumento


	/**
	 * [ORQUESTA] Dada una referencia GDE elimina el documento del gestor documental
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia/identificador del Doc en GDE
	 * @return	boolean	TRUE si borrado correcto, o false si no se realiza
	 * @access 	public
	 */
	public function eliminarDocumento($codApp, $refDoc)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__eliminarDocumento_full(
					array(
							'referenciaDocumento' => $refDoc
					), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'eliminarDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->eliminarDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					// Realiza la interpretacion/sustitucion estandar de MTOM
					$vRetorno = $this->tratarMTOMEstandar($response);
					return $vRetorno;
					break;

				case 'gde_gestordocumentalexception' :
					$mensaje = $e->detail->ExcepcionWS->detalleError;
					$mensaje = trim(strtolower($mensaje));
					if (strpos($mensaje, 'ya estaba borrado')===false)
					{
						$this->tratarExcepcionEstandar($e, $clienteWS);
					}
					else
					{
						return array(
								'respuesta'		=>	array('correcto'=>'false'),
								'codMotivo'		=> 'PREBORRADO',
								'motivo'		=> 'El documento ya haba sido borrado'
						);
					}
					break;

				case 'gde_documentonoexistenteexception':
					return array(
					'respuesta'		=>	array('correcto'=>'false'),
					'codMotivo'		=> 'NOEXISTE',
					'motivo'		=> 'No existe ningn documento con la referencia '.$refDoc
					);
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}//Fin catch
	}//eliminarDocumento



	/**
	 * Permite asociar firmas a un documento (incluyendo CSV)
	 *
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia/identificador del Doc en GDE
	 * @param array		$vFirmas Array asociativo con informacin de la firma
	 */
	public function asociarFirmas($codApp, $refDoc, $vFirmas)
	{

		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__asociarFirmas_full(array('referenciaDocumento' => $refDoc, 'firmas' => $vFirmas), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'asociarFirmas', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->asociarFirmas($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//asociarFirmas



	/**
	 * Realiza bsqueda de documentos estableciendo diferentes filtros de bsqueda.
	 *
	 * En caso de que se sobrepase un lmite preestablecido de resultados, se
	 * generar un error indicando que se debe restringir ms los filtros de
	 * bsqueda.
	 * En el caso de establecerse ms de un filtro se utilizar el campo
	 * operacin para realizar la consulta. En caso de no devolver ningn
	 * documento, se devolver un array vaco.
	 *
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param	string	$filtroPath Path relativo con respecto al espacio raz de la aplicacin. (Opcional)
	 * @param	string	$buscarInTree Buscar en el subespacio de aplicacin (true) o en todo GDE (false)
	 * @param	string	$operacion Indica la opertacin lgic (AND/OR)
	 * @param	array	$coleccionCriterios Coleccin de criterios de bsqueda {@link }
	 */
	public function buscarDocCriterio($codApp, $filtroPath=null, $buscarInTree=null, $operacion=null, $coleccionCriterios=null)
	{
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__buscarDocCriterio_full(array('filtroPath' => $filtroPath, 'buscarInTree' => $buscarInTree, 'operacion' => $operacion, 'coleccionCriterios' => $coleccionCriterios), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'buscarDocCriterio', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->buscarDocCriterio($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//buscarDocCriterio


	/**
	 * Realiza bsqueda de documentos estableciendo diferentes filtros de
	 * bsqueda. En caso de que se sobrepase un lmite preestablecido de
	 * resultados, se generar un error indicando que se debe restringir ms los
	 * filtros de bsqueda. En el caso de establecerse ms de un filtro se
	 * utilizar el campo operacin para realizar la consulta. En caso de no
	 * devolver ningn documento, se devolver un array vaco
	 *
	 * @param	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param	int	$registrosPagina Nmero de regitros por pgina
	 * @param	int	$pagina Pgina a recuperar (empezando por 1)
	 * @param	string	$filtroPath Path relativo con respecto al espacio raz de la aplicacin. (Opcional)
	 * @param	string	$buscarInTree Buscar en el subespacio de aplicacin (true) o en todo GDE (false)
	 * @param	string	$operacion Indica la operacin lgica (AND/OR)
	 * @param	array	$coleccionCriterios Coleccin de criterios de bsqueda
	 */
	public function buscarDocCriterioPaginado($codApp, $registrosPagina, $pagina, $filtroPath=null, $buscarInTree=null, $operacion=null, $coleccionCriterios=null) {
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__buscarDocCriterioPaginado_full(array('paginacion' => array('registrosPagina' => $registrosPagina, 'pagina' => $pagina), 'filtroPath' => $filtroPath, 'buscarInTree' => $buscarInTree, 'operacion' => $operacion, 'coleccionCriterios' => $coleccionCriterios), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'buscarDocCriterioPaginado', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->buscarDocCriterioPaginado($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//buscarDocCriterioPaginado



	/**
	 * Crea una carpeta con el path indicado en el espacio propio del usuario/aplicacin de GDE. Opcionalmente pueden indicarse metadatos para la misma
	 * @param string$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param string	$path	Ruta de ubicacin de la carpeta
	 * @param string $tipo	Tipos bsico
	 * @param array $metadatosExpedienteEni
	 * @param array $coleccionMetadatosPersonalizados
	 */
	public function crearCarpeta($codApp, $path, $tipo=null, $metadatosExpedienteEni=null, $coleccionMetadatosPersonalizados=null)
	{
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__crearCarpeta_full(
					array(
							'path' => $path,
							'tipoPersonalizado' => $tipo,
							'metadatosExpedienteEni' => $metadatosExpedienteEni,
							'coleccionMetadatosPersonalizados' => $coleccionMetadatosPersonalizados
					), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'crearCarpeta', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->crearCarpeta($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//crearCarpeta


	/**
	 * Borra una carpeta vaca y perteneciente a la aplicacin propietaria
	 * @param string $codApp	cdigo de aplicacin
	 * @param string $path		Ruta de la carpeta a eliminar
	 * @return object
	 */
	public function eliminarCarpeta($codApp, $path)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__eliminarCarpeta_full(
					array(
							'path' => $path
					), 'peticion', self::$NAMESPACE_GDE2);

			$obtenerDocumentoWSRequest = new \ArrayObject();
			$obtenerDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$obtenerDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'eliminarCarpeta', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->eliminarCarpeta($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//eliminarCarpeta



	/**
	 * Crea un paquete (documento) ENI  a partir del contenido, sus metadatos y las firmas
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $contenido 	Contenido del DOC
	 * @param array $vMetadatosEni	Array asociativo de metadatos ENI
	 * @param array $vFirmas		Array asociativo de firmas
	 */
	public function empaquetarDocumentoENI($codApp, $contenido, $vMetadatosEni, $vFirmas) {

		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__empaquetarDocumentoENI_full(array('contenido' => $contenido, 'metadatosENI' => $vMetadatosEni, 'firmas' => $vFirmas), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));


			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'empaquetarDocumentoENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->empaquetarDocumentoENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//empaquetarDocumentoENI


	/**
	 * Asigna o modifica los metadatos personalizados de la carpeta identificada en $path
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $path			Ruta a la carpeta
	 * @param array $vColMetadatosPers Array asociativo de metadatros personalizados
	 * @return object
	 */
	public function establecerMetadatoCarpetasPersonalizados($codApp, $path, $vColMetadatosPers) {
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__establecerMetadatoCarpetasPersonalizados_full(array('path' => $path, 'coleccionMetadatosPersonalizados' => $vColMetadatosPers), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));


			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'establecerMetadatoCarpetasPersonalizados', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->establecerMetadatoCarpetasPersonalizados($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//establecerMetadatoCarpetasPersonalizados

	/**
	 * Modifica los metadatos del Exp. Elec. ENI pasados por parmetros a la carpeta identificada por $path.
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $path
	 * @param array $vMetadatosExpedienteEni
	 */
	public function establecerMetadatosCarpetaExpedienteENI($codApp, $path, $vMetadatosExpedienteEni) {

		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__establecerMetadatosCarpetaExpedienteENI_full(array('path' => $path, 'metadatosExpedienteEni' => $vMetadatosExpedienteEni), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));


			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'establecerMetadatosCarpetaExpedienteENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->establecerMetadatosCarpetaExpedienteENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//establecerMetadatosCarpetaExpedienteENI


	/**
	 * Permite modificar los valores de los metadatos ENI del documento
	 *
	 * Existe informacin adicional aqu: {@link http://www.seap.minhap.gob.es/dms/es/publicaciones/centro_de_publicaciones_de_la_sgt/Monografias0/parrafo/Manual_XML/text_es_files/Manual_esquemas-XML-intercambio-doc-exp-elec-INTERNET.pdf}
	 *
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $refDoc
	 * @param array $vMetadatosEni
	 */
	public function establecerMetadatosENI($codApp, $refDoc, $vMetadatosEni)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__establecerMetadatosENI_full(array('referenciaDocumento' => $refDoc, 'metadatosENI' => $vMetadatosEni), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));


			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'establecerMetadatosENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->establecerMetadatosENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//establecerMetadatosENI


	/**
	 *
	 * @param string $codApp
	 * @param string $refDoc referencia GDE
	 * @param array $coleccionMetadatosPersonalizados
	 */
	public function establecerMetadatosPersonalizados($codApp, $refDoc, $coleccionMetadatosPersonalizados)
	{
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__establecerMetadatosPersonalizados_full(array('referenciaDocumento' => $refDoc, 'coleccionMetadatosPersonalizados' => $coleccionMetadatosPersonalizados), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));


			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'establecerMetadatosPersonalizados', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->establecerMetadatosPersonalizados($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//establecerMetadatosPersonalizados


	/**
	 * Genera identificador nico de documento basado en el formato definido por las normas NTI del ENI.
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 */
	public function generarIdentificadorENI($codApp)
	{

		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'generarIdentificadorENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->generarIdentificadorENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//generarIdentificadorENI


	/**
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param string	$vRefDoc
	 */
	public function generarToken($codApp, $vRefDoc)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__generarToken_full(array('referenciaDocumento' => $vRefDoc), 'peticion', self::$NAMESPACE_GDE2);

			$obtenerDocumentoWSRequest = new \ArrayObject();
			$obtenerDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$obtenerDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'generarToken', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->generarToken($miSoapRQ);


			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//generarToken


	/**
	 * Inserta documento ENI y devuelve referencia al documento.
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param string	$docContentB64	Contenido en B64 del doc.
	 * @param string	$nombreDoc Nombre del documento
	 * @param string	$pathDocRuta donde almacenar el doc (dentro de GDE)
	 * @param string	$tipo
	 * @param string	$vMetaENI Array asociativo de metadatos ENI
	 * @param string	$vMetaPers Array asociativo de metadatos personalizados
	 * @param string	$vFirmas
	 * @return array 	asociativo con la referencia GDE y el nombre doc
	 */
	public function insertarDocumentoENI($codApp, $docContentB64, $nombreDoc, $pathDoc=null, $tipo=null, $vMetaENI=null, $vMetaPers=null, $vFirmas=null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_GDE2, true);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_GDE2];

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__insertarDocumentoENI_full(array('documentoENI' => $docContentB64, 'nombre' => $nombreDoc,
					'path' => $pathDoc, 'tipoPersonalizado' => $tipo, 'metadatosENI' => $vMetaENI, 'coleccionMetadatosPersonalizados' => $vMetaPers, 'firmas' => $vFirmas), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'insertarDocumentoENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->insertarDocumentoENI($miSoapRQ);


			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = array
				(
						'referenciaDocumento' =>$respuesta->respuesta->referenciaDocumento,
						'nombre' => $respuesta->respuesta->nombre
				);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//insertarDocumentoENI


	/**
	 * Obtiene un Documento de un espacin GDE a partir de la referencia
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string 	$refDoc	Referencia/identificador del documento
	 * @return array	Array asociativo con los datos (y el contenido) del Doc
	 */
	public function obtenerDocumentoENI($codApp, $refDoc)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__obtenerDocumentoENI_full(
					array(
							'referenciaDocumento' => $refDoc
					), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'obtenerDocumentoENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerDocumentoENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//obtenerDocumentoENI


	/**
	 * Utilizando los documentos y metadatos pasados por parmetro, se genera,
	 * tanto el ndice del expediente electrnico ENI como su versin visualizable
	 * en PDF, se firma el ndice, y se construye, segn los XSD de la norma,
	 * devolvindose el expediente electrnico ENI, empaquetado en un ZIP.
	 * En el caso de que no se le pase el parmetro datosCertificado, el ndice
	 * se firmar con el que se configure para el usuario/aplicacin en el GDE.
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string 	$refDoc	Referencia/identificador del documento
	 * @param array 	$vMetadatosExpedienteEni Array asociativo de metadatos ENI
	 * @param array		$idCertificadoSafe
	 * @param array		$idSesionSafe
	 * @return array Array asociativo con los datos y metadatos del expediente
	 */
	public function obtenerExpedienteENI($codApp, $refDoc, $vMetadatosExpedienteEni, $idCertificadoSafe = null, $idSesionSafe = null)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__obtenerExpedienteENI_full(array('referenciaDocumento' => $refDoc, 'datosCertificado' => array('idCertificadoSafe' => $idCertificadoSafe, 'idSesionSafe' => $idSesionSafe), 'metadatosExpedienteEni' => $vMetadatosExpedienteEni), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'obtenerExpedienteENI', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerExpedienteENI($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//obtenerExpedienteENI


	/**
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string $path
	 * @param string $idCertificadoSafe
	 * @param string $idSesionSafe
	 * @return object|array
	 */
	public function obtenerExpedienteENIdeCarpeta($codApp, $path, $idCertificadoSafe = null, $idSesionSafe = null)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('path' => $path);
			if (!is_null($idCertificadoSafe) && !is_null($idSesionSafe)) {
				$vDataPeticion = array('path' => $path, 'datosCertificado' => array('idCertificadoSafe' => $idCertificadoSafe, 'idSesionSafe' => $idSesionSafe));
			}
			$peticionWSRequest = $composer->__cde__obtenerExpedienteENIdeCarpeta_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'obtenerExpedienteENIdeCarpeta', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerExpedienteENIdeCarpeta($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			// Comprobamos si estamos ante excepcion MTOM
			$mensaje = $e->getMessage();
			$mensaje = trim(strtolower($mensaje));
			switch ($mensaje)
			{
				case 'looks like we got no xml document' :
					// Obtiene la respuesta
					$response = $clienteWS->__getLastResponse();
					$respuesta = $this->tratarMTOMEstandar($response);
					return $respuesta;
					break;

				default:
					$this->aislarExcepcionGDE($e, $clienteWS);
					break;
			}
		}
	}//obtenerExpedienteENIdeCarpeta




	/*****************************************************************************/
	/*                              NUEVOS METODOS                               */
	/*****************************************************************************/

	/**
	 * Este mtodo mueve el documento especificado a otra carpeta.
	 * Si la nueva carpeta no existe, la crea.
	 * Mueve tanto el documento, como las firmas de ste.
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia del documento
	 * @param  	string	$pathDestino	Path  relativo con respecto al espacio raz de la app
	 * @return	array 	Respuesta del servicio indicando la correccion de la operacion
	 * @access 	public
	 */
	public function moverDocumento($codApp, $refDoc, $pathDestino)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('referenciaDocumento' => $refDoc, 'pathDestino' => $pathDestino);
			$peticionWSRequest = $composer->__cde__moverDocumento_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'moverDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->moverDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//moverDocumento


	/**
	 * Permite actualizar un documento ya existente.
	 * Se generarn dos versiones, una que contendr una copia exacta de la versin
	 * anterior y una segunda copia que ser la versin modificada, cuyo nmero de
	 * versin ser devuelto en la respuesta
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia del documento
	 * @param  	string	$docContentB64	Contenido del documento en Base64
	 * @param  	array 	$vFirmas Opcional. Array asociativo. Firmas
	 * @return	array 	Respuesta del servicio, indicando el nmero de versin generada
	 * @access 	public
	 */
	public function actualizarDocumento($codApp, $refDoc, $docContentB64, $vFirmas=null)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_GDE2, true);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_GDE2];

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__actualizarDocumento_full(
					array(
							'referenciaDocumento' => $refDoc,
							'contenido' => $docContentB64,
							'firmas' => $vFirmas
					), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'actualizarDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->actualizarDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//actualizarDocumento


	/**
	 * Permite obtener una lista de etiquetas con las versiones guardadas del documento
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia del documento
	 * @return	array 	Respuesta del servicio, indicando la lista de versiones del documento
	 * @access 	public
	 */
	public function obtenerListaVersionesDocumento($codApp, $refDoc){
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('referenciaDocumento' => $refDoc);
			$peticionWSRequest = $composer->__cde__obtenerListaVersionesDocumento_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$WSRequest = new \ArrayObject();
			$WSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$WSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($WSRequest, SOAP_ENC_OBJECT,null,null,'obtenerListaVersionesDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerListaVersionesDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//obtenerListaVersionesDocumento


	/**
	 * Permite restaurar una versin concreta del documento.
	 * Primero genera una copia exacta de la versin actual del documento y a continuacin,
	 * recupera la versin especificada aadindola como una nueva versin.
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia del documento
	 * @param  	string	$version	Etiqueta  de  versin  que  se quiere restaurar
	 * @param  	string	$parcial	Indica que datos recuprar (1: Todo, 2: Contenido y metadatos, 3: Contenido, metadatos y eliminar aquellos metadatos que no estn en la versin restaurada)
	 * @return	array 	Respuesta del servicio indicando la correccion de la operacion
	 * @access 	public
	 */
	public function restaurarVersionDocumento($codApp, $refDoc, $version, $parcial){
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('referenciaDocumento' => $refDoc, 'version' => $version, 'parcial' => $parcial);
			$peticionWSRequest = $composer->__cde__restaurarVersionDocumento_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$obtenerDocumentoWSRequest = new \ArrayObject();
			$obtenerDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$obtenerDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'restaurarVersionDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->restaurarVersionDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//restaurarVersionDocumento


	/**
	 * Permite, a partir de una referencia de documento, obtener la ruta del documento en el espacio asignado a la aplicacin propietaria.
	 * El path del documento, debe estar dentro de root_custom.
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia del documento
	 * @return	array 	Respuesta del servicio, indicando la ruta relativa del documento a partir del espacio "root_custom de la aplicacin
	 * @access 	public
	 */
	public function obtenerPathDocumento($codApp, $refDoc){
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('referenciaDocumento' => $refDoc);
			$peticionWSRequest = $composer->__cde__obtenerPathDocumento_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'obtenerPathDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerPathDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//obtenerPathDocumento


	/**
	 * Permite eliminar de forma recursiva una carpeta
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$path	Ruta relativa de la carpeta que queremos  borrar. La  ruta introducida buscar a partir del directorio root_custom
	 * @return	array 	Respuesta del servicio indicando la correccion de la operacion
	 * @access 	public
	 */
	public function eliminarCarpetaRecursiva($codApp, $path)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__eliminarCarpetaRecursiva_full(array('path' => $path), 'peticion', self::$NAMESPACE_GDE2);

			$obtenerDocumentoWSRequest = new \ArrayObject();
			$obtenerDocumentoWSRequest->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$obtenerDocumentoWSRequest->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($obtenerDocumentoWSRequest, SOAP_ENC_OBJECT,null,null,'eliminarCarpetaRecursiva', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->eliminarCarpetaRecursiva($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//eliminarCarpetaRecursiva


	/**
	 * Permite, mover o renombrar una carpeta. Las rutas siempre se buscarn y se crearn en root_custom
	 *
	 * @subpackage 	GDE2
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$pathOrigen	Ruta relativa de la carpeta que queremos mover o renombrar
	 * @param  	string	$pathDestino	Ruta relativa de la carpeta que queremos mover o renombrar
	 * @return	array 	Respuesta del servicio indicando la correccion de la operacion
	 * @access 	public
	 */
	public function moverCarpeta($codApp, $pathOrigen, $pathDestino){
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);


			$composer = new ComposerGDE2();
			$vDataPeticion = array('pathOrigen' => $pathOrigen, 'pathDestino' => $pathDestino);
			$peticionWSRequest = $composer->__cde__moverCarpeta_full($vDataPeticion, 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'moverCarpeta', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->moverCarpeta($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//moverCarpeta


	/**
	 * Accede al doc y devuelve la informacin de una version concreta del mismo
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia Alfresco del Doc
	 * @param  	string	$parcial	Indica que datos recuperar (??? 1: Todo, 2: Contenido, 3: Metadatos, 4: Metadatos y Firmas)
	 * @param  	string	$version	Etiqueta de versin que se quiere recuperar
	 * @return	array	Array asociativo [contenido|nombre|tipoPersonalizado|borrado|metadatosENI|metadatosPersonalizados|firmas]
	 * @access 	public
	 */
	public function obtenerVersionDocumento($codApp, $refDoc, $parcial, $version)
	{
		//$this->setDebugMode(true);
		try
		{
			$opcionesClienteWS = array (
					'soap_version' => SOAP_1_1, //SOAP 1.2
					'user_agent' => 'WSSSoapClient',
					'exceptions' => true,
					'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
					'trace' => self::$MYSOAPOP_TRACE
			);

			$this->__clienteOn(self::KEYCLIENTE_GDE2, true, $opcionesClienteWS);
			$clienteWS = $this->__getClient(self::KEYCLIENTE_GDE2);

			$composer = new ComposerGDE2();
			$peticionWSRequest = $composer->__cde__obtenerVersionDocumento_full(
					array(
							'referenciaDocumento' => $refDoc,
							'parcial'			  => $parcial,
							'version'			  => $version
					), 'peticion', self::$NAMESPACE_GDE2);

			$mainWS = new \ArrayObject();
			$mainWS->append(new \SoapVar($codApp, XSD_STRING, null, null,'codigoAplicacion', self::$NAMESPACE_GDE2));
			$mainWS->append(new \SoapVar($peticionWSRequest, SOAP_ENC_OBJECT,null,null,'peticion', self::$NAMESPACE_GDE2));

			$miSoapRQ = new \SoapVar($mainWS, SOAP_ENC_OBJECT,null,null,'obtenerVersionDocumento', self::$NAMESPACE_GDE2);
			$respuesta = $clienteWS->obtenerVersionDocumento($miSoapRQ);

			$vRespuesta = array();
			if (is_object($respuesta))
			{
				$vRespuesta = $this->objectTree2array($respuesta);
			}
			return($vRespuesta);
		}
		catch (\Exception $e)
		{
			return $this->tratarInnerException($clienteWS, $e);
		}
	}//obtenerVersionDocumento



	/*****************************************************************************/
	/*                         AUXILIARES DE FRONT END                           */
	/*****************************************************************************/


	/**
	 * Devuelve una URL en la que obtener el documento a partir del token suministrado
	 *
	 * @subpackage 	GDE2
	 * @param  	bool	$esProduccion	Indica si debe realizarse la peticion al servidor de produccion o al servidor de desarrollo/preproduccion
	 * @param  	string	$token	Token vlido para la descarga del documento
	 * @return	string 	URL parametrizada a la que realizar la consulta
	 * @access 	public
	 */
	public function front_obtenerDocumentoAPartirDeToken($esProduccion, $token){
		// Compone la URL de la peticion
		$urlPeticion = URL_FRONT_DESARROLLO;
		if ($esProduccion) {
			$urlPeticion = URL_FRONT_PRODUCCION;
		}

		return $urlPeticion . 'getToken?token=' . $token;
	}//front_obtenerDocumentoAPartirDeToken


	/**
	 * Devuelve una URL en la que obtener un  identificador  GDE  y  la  ruta  a  su  directorio  raz
	 * La URL resultante devolver una cadena con los dos valores con el separador #@#: idGDE#@#path_root
	 *
	 * @subpackage 	GDE2
	 * @param  	bool	$esProduccion	Indica si debe realizarse la peticion al servidor de produccion o al servidor de desarrollo/preproduccion
	 * @param  	string	$codApp	Nombre del espacio de la aplicacion
	 * @param  	string	$refDoc	Referencia del documento
	 * @return	string 	URL parametrizada a la que realizar la consulta
	 * @access 	public
	 */
	public function front_obtenerIdentificadorGDE($esProduccion, $codApp, $refDoc){
		// Compone la URL de la peticion
		$urlPeticion = URL_FRONT_DESARROLLO;
		if ($esProduccion) {
			$urlPeticion = URL_FRONT_PRODUCCION;
		}

		return $urlPeticion . 'getId?codigoAplicacion=' . $codApp . '&ref=' . $refDoc;
	}//front_obtenerIdentificadorGDE




	/*****************************************************************************/
	/*                      NOMENCLATURA ANTIGUA - OBSOLETA                      */
	/*****************************************************************************/


	/**
	 * [Obsoleto] Vase: insertarDocumento
	 * Inserta doc segn parmetros recibidos y devuelve referencia al mismo
	 *
	 * No se requerir especificar las firmas, los metadatos del ENI o los
	 * metadatos personalizados. Esto permitir el uso por parte de aplicaciones
	 * que no requieran de intercambio de documentos ENI. Si se especifican
	 * metadatosEni y el Identificador ENI no viene informado, se generar
	 * automticamente por parte del GDE. Si no se indica el path se almacenar
	 * de forma automtica. En caso de que se indique path se establecer en
	 * el path indicado.
	 * @subpackage 	GDE
	 * @deprecated
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$docContentB64	Contenido del documento en Base64
	 * @param  	string	$nombreDoc	Nombre Doc.
	 * @param  	string	$pathDoc	Path relativo al espacio raz de la app
	 * @param  	array	$vMetadatosENI	Opcional. Array asociativo con meta informacin ENI [versionNTI|identificador|tipoDocumental|nombreFormatoorgano|fechaCaptura|estadoElaboracion|origenCiudadanoAdministracion|identificadorDocumentoOrigen]
	 * @param  	array	$vMetadatosPersonalizados	Opcional. Array asociativo. [idColeccionMetadatosPersonalizados|metadatosPersonalizados]
	 * @return	array 	$vFirmas Opcional. Array asociativo. Firmas
	 * @access 	public
	 */
	public function insertarDocumentoGDE2($codApp, $docContentB64, $nombreDoc, $pathDoc=null, $tipo = null, $vMetadatosENI = null, $vMetadatosPersonalizados=null, $vFirmas=null)
	{
		return $this->insertarDocumento($codApp, $docContentB64, $nombreDoc, $pathDoc, $tipo, $vMetadatosENI, $vMetadatosPersonalizados, $vFirmas);
	}//insertarDocumentoGDE2



	/**
	 * [Obsoleto] Vase: obtenerDocumento
	 * [ORQUESTA] Accede al doc y devuelva la informacin asocaida al msimo
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia Alfresco del Doc
	 * @param  	string	$parcial Indica que datos recuprar (1: Todo, 2: Contenido, 3: MEtadatos, 4: Metadatos y Firmas)
	 * @return	array	Array asociativo [contenido|nombre|borrado|metadatosENI|metadatosPersonalizados|firmas]
	 * @access 	public
	 */
	public function obtenerDocumentoGDE2($codApp, $refDoc, $parcial='1')
	{
		return $this->obtenerDocumento($codApp, $refDoc, $parcial);
	}//obtenerDocumentoGDE2


	/**
	 * [Obsoleto] Vase: eliminarDocumento
	 * [ORQUESTA] Dada una referencia GDE elimina el documento del gestor documental
	 *
	 * @subpackage 	GDE
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia/identificador del Doc en GDE
	 * @return	boolean	TRUE si borrado correcto, o false si no se realiza
	 * @access 	public
	 */
	public function eliminarDocumentoGDE2($codApp, $refDoc)
	{
		return $this->eliminarDocumento($codApp, $refDoc);
	}//eliminarDocumentoGDE2



	/**
	 * [Obsoleto] Vase: asociarFirmas
	 * Permite asociar firmas a un documento (incluyendo CSV)
	 *
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param  	string	$refDoc	Referencia/identificador del Doc en GDE
	 * @param array		$vFirmas Array asociativo con informacin de la firma
	 */
	public function asociarFirmasGDE2($codApp, $refDoc, $vFirmas)
	{
		return $this->asociarFirmas($codApp, $refDoc, $vFirmas);
	}//asociarFirmasGDE2



	/**
	 * [Obsoleto] Vase: buscarDocCriterio
	 * Realiza bsqueda de documentos estableciendo diferentes filtros de bsqueda.
	 *
	 * En caso de que se sobrepase un lmite preestablecido de resultados, se
	 * generar un error indicando que se debe restringir ms los filtros de
	 * bsqueda.
	 * En el caso de establecerse ms de un filtro se utilizar el campo
	 * operacin para realizar la consulta. En caso de no devolver ningn
	 * documento, se devolver un array vaco.
	 *
	 * @param  	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param	string	$filtroPath Path relativo con respecto al espacio raz de la aplicacin. (Opcional)
	 * @param	string	$buscarInTree Buscar en el subespacio de aplicacin (true) o en todo GDE (false)
	 * @param	string	$operacion Indica la opertacin lgic (AND/OR)
	 * @param	array	$coleccionCriterios Coleccin de criterios de bsqueda {@link }
	 */
	public function buscarDocCriterioGDE2($codApp, $filtroPath=null, $buscarInTree=null, $operacion=null, $coleccionCriterios=null)
	{
		return $this->buscarDocCriterio($codApp, $filtroPath, $buscarInTree, $operacion, $coleccionCriterios);
	}//buscarDocCriterioGDE2


	/**
	 * [Obsoleto] Vase: buscarDocCriterioPaginado
	 * Realiza bsqueda de documentos estableciendo diferentes filtros de
	 * bsqueda. En caso de que se sobrepase un lmite preestablecido de
	 * resultados, se generar un error indicando que se debe restringir ms los
	 * filtros de bsqueda. En el caso de establecerse ms de un filtro se
	 * utilizar el campo operacin para realizar la consulta. En caso de no
	 * devolver ningn documento, se devolver un array vaco
	 *
	 * @param	string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param	int		$registrosPagina Nmero de regitros por pgina
	 * @param	int		$pagina Pgina a recuperar (empezando por 1)
	 * @param	string	$filtroPath Path relativo con respecto al espacio raz de la aplicacin. (Opcional)
	 * @param	string	$buscarInTree Buscar en el subespacio de aplicacin (true) o en todo GDE (false)
	 * @param	string	$operacion Indica la operacin lgica (AND/OR)
	 * @param	array	$coleccionCriterios Coleccin de criterios de bsqueda
	 */
	public function buscarDocCriterioPaginadoGDE2($codApp, $registrosPagina, $pagina, $filtroPath=null, $buscarInTree=null, $operacion=null, $coleccionCriterios=null)
	{
		return $this->buscarDocCriterioPaginado($codApp, $registrosPagina, $pagina, $filtroPath, $buscarInTree, $operacion, $coleccionCriterios);
	}//buscarDocCriterioPaginadoGDE2



	/**
	 * [Obsoleto] Vase: crearCarpeta
	 * Crea una carpeta con el path indicado en el espacio propio del usuario/aplicacin de GDE. Opcionalmente pueden indicarse metadatos para la misma
	 * @param string$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param string	$path	Ruta de ubicacin de la carpeta
	 * @param string $tipo	Tipos bsico
	 * @param array $metadatosExpedienteEni
	 * @param array $coleccionMetadatosPersonalizados
	 */
	public function crearCarpetaGDE2($codApp, $path, $tipo=null, $metadatosExpedienteEni=null, $coleccionMetadatosPersonalizados=null)
	{
		return $this->crearCarpeta($codApp, $path, $tipo, $metadatosExpedienteEni, $coleccionMetadatosPersonalizados);
	}//crearCarpetaGDE2


	/**
	 * [Obsoleto] Vase: eliminarCarpeta
	 * Borra una carpeta vaca y perteneciente a la aplicacin propietaria
	 * @param string $codApp	cdigo de aplicacin
	 * @param string $path		Ruta de la carpeta a eliminar
	 * @return object
	 */
	public function eliminarCarpetaGDE2($codApp, $path)
	{
		return $this->eliminarCarpeta($codApp, $path);
	}//eliminarCarpetaGDE2



	/**
	 * [Obsoleto] Vase: empaquetarDocumentoENI
	 * Crea un paquete (documento) ENI  a partir del contenido, sus metadatos y las firmas
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $contenido 	Contenido del DOC
	 * @param array $vMetadatosEni	Array asociativo de metadatos ENI
	 * @param array $vFirmas		Array asociativo de firmas
	 */
	public function empaquetarDocumentoENIGDE2($codApp, $contenido, $vMetadatosEni, $vFirmas)
	{
		return $this->empaquetarDocumentoENI($codApp, $contenido, $vMetadatosEni, $vFirmas);
	}//empaquetarDocumentoENIGDE2


	/**
	 * [Obsoleto] Vase: establecerMetadatoCarpetasPersonalizados
	 * Asigna o modifica los metadatos personalizados de la carpeta identificada en $path
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $path			Ruta a la carpeta
	 * @param array $vColMetadatosPers Array asociativo de metadatros personalizados
	 * @return object
	 */
	public function establecerMetadatoCarpetasPersonalizadosGDE2($codApp, $path, $vColMetadatosPers)
	{
		return $this->establecerMetadatoCarpetasPersonalizados($codApp, $path, $vColMetadatosPers);
	}//establecerMetadatoCarpetasPersonalizadosGDE2

	/**
	 * [Obsoleto] Vase: establecerMetadatosCarpetaExpedienteENI
	 * Modifica los metadatos del Exp. Elec. ENI pasados por parmetros a la carpeta identificada por $path.
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $path
	 * @param array $vMetadatosExpedienteEni
	 */
	public function establecerMetadatosCarpetaExpedienteENIGDE2($codApp, $path, $vMetadatosExpedienteEni)
	{
		return $this->establecerMetadatosCarpetaExpedienteENI($codApp, $path, $vMetadatosExpedienteEni);
	}//establecerMetadatosCarpetaExpedienteENIGDE2


	/**
	 * [Obsoleto] Vase: establecerMetadatosENI
	 * Permite modificar los valores de los metadatos ENI del documento
	 *
	 * Existe informacin adicional aqu: {@link http://www.seap.minhap.gob.es/dms/es/publicaciones/centro_de_publicaciones_de_la_sgt/Monografias0/parrafo/Manual_XML/text_es_files/Manual_esquemas-XML-intercambio-doc-exp-elec-INTERNET.pdf}
	 *
	 * @param string $codApp		cdigo de aplicacin
	 * @param string $refDoc
	 * @param array $vMetadatosEni
	 */
	public function establecerMetadatosENIGDE2($codApp, $refDoc, $vMetadatosEni)
	{
		return $this->establecerMetadatosENI($codApp, $refDoc, $vMetadatosEni);
	}//establecerMetadatosENIGDE2


	/**
	 * [Obsoleto] Vase: establecerMetadatosPersonalizados
	 *
	 * @param string $codApp
	 * @param string $refDoc referencia GDE
	 * @param array $coleccionMetadatosPersonalizados
	 */
	public function establecerMetadatosPersonalizadosGDE2($codApp, $refDoc, $coleccionMetadatosPersonalizados)
	{
		return $this->establecerMetadatosPersonalizados($codApp, $refDoc, $coleccionMetadatosPersonalizados);
	}//establecerMetadatosPersonalizadosGDE2


	/**
	 * [Obsoleto] Vase: generarIdentificadorENI
	 * Genera identificador nico de documento basado en el formato definido por las normas NTI del ENI.
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 */
	public function generarIdentificadorENIGDE2($codApp)
	{
		return $this->generarIdentificadorENI($codApp);
	}//generarIdentificadorENIGDE2


	/**
	 * [Obsoleto] Vase: generarToken
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param array		$vRefDoc
	 */
	public function generarTokenGDE2($codApp, $vRefDoc)
	{
		return $this->generarToken($codApp, $vRefDoc);
	}//generarTokenGDE2


	/**
	 * [Obsoleto] Vase: insertarDocumentoENI
	 * Inserta documento ENI y devuelve referencia al documento.
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante.
	 * @param string	$docContentB64	Contenido en B64 del doc.
	 * @param string	$nombreDoc Nombre del documento
	 * @param string	$pathDocRuta donde almacenar el doc (dentro de GDE)
	 * @param string	$tipo
	 * @param string	$vMetaENI Array asociativo de metadatos ENI
	 * @param string	$vMetaPers Array asociativo de metadatos personalizados
	 * @param string	$vFirmas
	 * @return array 	asociativo con la referencia GDE y el nombre doc
	 */
	public function insertarDocumentoENIGDE2($codApp, $docContentB64, $nombreDoc, $pathDoc=null, $tipo=null, $vMetaENI=null, $vMetaPers=null, $vFirmas=null)
	{
		return $this->insertarDocumentoENI($codApp, $docContentB64, $nombreDoc, $pathDoc, $tipo, $vMetaENI, $vMetaPers, $vFirmas);
	}//insertarDocumentoENIGDE2


	/**
	 * [Obsoleto] Vase: obtenerDocumentoENI
	 * Obtiene un Documento de un espacin GDE a partir de la referencia
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string 	$refDoc	Referencia/identificador del documento
	 * @return array	Array asociativo con los datos (y el contenido) del Doc
	 */
	public function obtenerDocumentoENIGDE2($codApp, $refDoc)
	{
		return $this->obtenerDocumentoENI($codApp, $refDoc);
	}//obtenerDocumentoENIGDE2


	/**
	 * [Obsoleto] Vase: obtenerExpedienteENI
	 * Utilizando los documentos y metadatos pasados por parmetro, se genera,
	 * tanto el ndice del expediente electrnico ENI como su versin visualizable
	 * en PDF, se firma el ndice, y se construye, segn los XSD de la norma,
	 * devolvindose el expediente electrnico ENI, empaquetado en un ZIP.
	 * En el caso de que no se le pase el parmetro datosCertificado, el ndice
	 * se firmar con el que se configure para el usuario/aplicacin en el GDE.
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string 	$refDoc	Referencia/identificador del documento
	 * @param array 	$vMetadatosExpedienteEni Array asociativo de metadatos ENI
	 * @param array		$idCertificadoSafe
	 * @param array		$idSesionSafe
	 * @return array Array asociativo con los datos y metadatos del expediente
	 */
	public function obtenerExpedienteENIGDE2($codApp, $refDoc, $vMetadatosExpedienteEni, $idCertificadoSafe = null, $idSesionSafe = null)
	{
		return $this->obtenerExpedienteENI($codApp, $refDoc, $vMetadatosExpedienteEni, $idCertificadoSafe, $idSesionSafe);
	}//obtenerExpedienteENIGDE2

	/**
	 * [Obsoleto] Vase: obtenerExpedienteENIdeCarpeta
	 *
	 * @param string	$codApp	Cdigo del espacio de aplicacin invocante (espacio)
	 * @param string $path
	 * @param string $idCertificadoSafe
	 * @param string $idSesionSafe
	 * @return object|array
	 */
	public function obtenerExpedienteENIdeCarpetaGDE2($codApp, $path, $idCertificadoSafe = null, $idSesionSafe = null)
	{
		return $this->obtenerExpedienteENIdeCarpeta($codApp, $path, $idCertificadoSafe, $idSesionSafe);
	}//obtenerExpedienteENIdeCarpetaGDE2






	/**
	 * Tratamiento estandarizado de las excepciones producidas en la invocacion al WS de GDE2
	 *
	 * @param object	$clienteWS clienteWS utilizado en la peticion al Servicio Web
	 * @param object	$e Excepcion producida
	 */
	private function tratarInnerException($clienteWS, $e)
	{
		// Comprobamos si estamos ante excepcion MTOM
		$mensaje = $e->getMessage();
		$mensaje = trim(strtolower($mensaje));
		switch ($mensaje)
		{
			case 'looks like we got no xml document' :
				// Obtiene la respuesta
				$response = $clienteWS->__getLastResponse();
				$respuesta = $this->tratarMTOMEstandar($response);
				return $respuesta;
				break;

			default:
				$this->aislarExcepcionGDE($e, $clienteWS);
				break;
		}
	}//tratarInnerException


	/**
	 * Intenta identificar si la excepcion es una excepcion propia de GDE2, en cuyo caso lanza
	 * una excepcion especializada GDE2Exception, en lugar de la excepcion original
	 *
	 * @param object	$clienteWS clienteWS utilizado en la peticion al Servicio Web
	 * @param object	$e Excepcion producida
	 */
	private function aislarExcepcionGDE($e, $clienteWS)
	{
		$tratado = false;


		// Si es un SoapFault y su codigo es soap::Server, asumimos que se trata de una excepcion GDE2
		if ($e instanceof \SoapFault) {
			if ($e->faultcode == 'soap:Server') {

				// Determina si es una excepcion detallada o no
				if (isset($e->detail)) {
					// Excepcion GDE2 detallada (Debe contener un objeto ExcepcionWS en su "detail")
					throw new GDE2Exception(GDE2Exception::getCodeFromFaultCode($e->faultstring), $e->faultstring, $e->detail->ExcepcionWS);
				} else {
					// Excepcion GDE2 generica (No contiene un objeto ExcepcionWS y no informa del tipo de excepcion exacto)
					throw new GDE2Exception(GDE2Exception::CODE_Desconocido, $e->getMessage());
				}
			}
		}

		// Si aun no se ha tratado la excepcion, la trata como una excepcion normal
		if (!$tratado) {
			$this->tratarExcepcionEstandar($e, $clienteWS);
		}
	}//aislarExcepcionGDE

}




/**
 *
 * GDE2Excepcion
 *
 */

class GDE2Exception extends \Exception
{

	/**
	 * Constantes para codigos de error GDE
	 */
	const CODE_Desconocido = 0;
	const CODE_UsuarioNoAutorizado = 1;
	const CODE_AplicacionNoExistente = 2;
	const CODE_GestorDocumental = 3;
	const CODE_LimiteRegistrosSobrepasado = 4;
	const CODE_IdentificadorENINoValido = 5;
	const CODE_EniConverterter = 6;
	const CODE_DocumentoNoInteroperable = 7;
	const CODE_TokenYaUtilizado = 8;
	const CODE_TokenCaducado = 9;
	const CODE_TokenIncorrecto = 10;
	const CODE_ExpedienteNoInteroperable = 11;
	const CODE_XMLExpedienteNoValido = 12;
	const CODE_DocumentoVacio = 13;
	const CODE_DocumentoNoExistente = 14;
	const CODE_PathAutoNoDisponible = 15;

	/**
	 * Constantes para mensjaes de error GDE
	 */
	const MSG_UsuarioNoAutorizado = 'GDE_UsuarioNoAutorizadoException';
	const MSG_AplicacionNoExistente = 'GDE_AplicacionNoExistenteException';
	const MSG_GestorDocumental = 'GDE_GestorDocumentalException';
	const MSG_LimiteRegistrosSobrepasado = 'GDE_LimiteRegistrosSobrepasadoException';
	const MSG_IdentificadorENINoValido = 'GDE_IdentificadorENINoValidoException';
	const MSG_EniConverterter = 'GDE_EniConverterterException';
	const MSG_DocumentoNoInteroperable = 'GDE_DocumentoNoInteroperableException';
	const MSG_TokenYaUtilizado = 'GDE_TokenYaUtilizadoException';
	const MSG_TokenCaducado = 'GDE_TokenCaducadoException';
	const MSG_TokenIncorrecto = 'GDE_TokenIncorrectoException';
	const MSG_ExpedienteNoInteroperable = 'GDE_ExpedienteNoInteroperableException';
	const MSG_XMLExpedienteNoValido = 'GDE_XMLExpedienteNoValidoException';
	const MSG_DocumentoVacio = 'GDE_DocumentoVacioException';
	const MSG_DocumentoNoExistente = 'GDE_DocumentoNoExistenteException';
	const MSG_PathAutoNoDisponible = 'GDE_PathAutoNoDisponibleException';


	/**
	 * Campo ExceptionWS propio de las excepciones GDE2
	 */
	private $exceptionWS = null;


	/**
	 * Devuelve el contenido del campo ExceptionWS propio de las excepciones GDE2
	 *
	 * @return	object
	 */
	public function getExceptionWS() {
		return $this->exceptionWS;
	}


	public function __construct($code, $message, $exceptionWS = null) {
		// asegrese de que todo est asignado apropiadamente
		parent::__construct($message, $code);

		$this->exceptionWS = $exceptionWS;
	}

	public function __toString() {
		return __CLASS__ . ": [{$this->code}]: {$this->message}\n";
	}


	/**
	 * Devuelve la cadena de texto vinculada al codigo de excepcion
	 *
	 * @return	string
	 */
	public function getCodeAsString() {
		switch ($this->getCode()) {
			case GDE2Exception::CODE_UsuarioNoAutorizado:
				return "UsuarioNoAutorizado";
				break;

			case GDE2Exception::CODE_AplicacionNoExistente:
				return "AplicacionNoExistente";
				break;

			case GDE2Exception::CODE_GestorDocumental:
				return "GestorDocumental";
				break;

			case GDE2Exception::CODE_LimiteRegistrosSobrepasado:
				return "LimiteRegistrosSobrepasado";
				break;

			case GDE2Exception::CODE_IdentificadorENINoValido:
				return "IdentificadorENINoValido";
				break;

			case GDE2Exception::CODE_EniConverterter:
				return "EniConverterter";
				break;

			case GDE2Exception::CODE_DocumentoNoInteroperable:
				return "DocumentoNoInteroperable";
				break;

			case GDE2Exception::CODE_TokenYaUtilizado:
				return "TokenYaUtilizado";
				break;

			case GDE2Exception::CODE_TokenCaducado:
				return "TokenCaducado";
				break;

			case GDE2Exception::CODE_TokenIncorrecto:
				return "TokenIncorrecto";
				break;

			case GDE2Exception::CODE_ExpedienteNoInteroperable:
				return "ExpedienteNoInteroperable";
				break;

			case GDE2Exception::CODE_XMLExpedienteNoValido:
				return "XMLExpedienteNoValido";
				break;

			case GDE2Exception::CODE_DocumentoVacio:
				return "DocumentoVacio";
				break;

			case GDE2Exception::CODE_DocumentoNoExistente:
				return "DocumentoNoExistente";
				break;

			case GDE2Exception::CODE_PathAutoNoDisponible:
				return "PathAutoNoDisponible";
				break;

			case GDE2Exception::CODE_Desconocido:
			default:
				return "Desconocido";
				break;
		}
	}


	/**
	 * Devuelve la cadena de texto vinculada al codigo de excepcion
	 *
	 * @param	string	$faultcode	Mensaje de error identificativo de la excepcion GDE2 (p.e.: GDE_DocumentoNoExistenteException)
	 * @return	integer	Codigo numerico identificativo del error GDE2
	 */
	public static function getCodeFromFaultCode($faultcode) {
		if ($faultcode == GDE2Exception::MSG_UsuarioNoAutorizado) {
			return GDE2Exception::CODE_UsuarioNoAutorizado;
		}
		if ($faultcode == GDE2Exception::MSG_AplicacionNoExistente) {
			return GDE2Exception::CODE_AplicacionNoExistente;
		}
		if ($faultcode == GDE2Exception::MSG_GestorDocumental) {
			return GDE2Exception::CODE_GestorDocumental;
		}
		if ($faultcode == GDE2Exception::MSG_LimiteRegistrosSobrepasado) {
			return GDE2Exception::CODE_LimiteRegistrosSobrepasado;
		}
		if ($faultcode == GDE2Exception::MSG_IdentificadorENINoValido) {
			return GDE2Exception::CODE_IdentificadorENINoValido;
		}
		if ($faultcode == GDE2Exception::MSG_EniConverterter) {
			return GDE2Exception::CODE_EniConverterter;
		}
		if ($faultcode == GDE2Exception::MSG_DocumentoNoInteroperable) {
			return GDE2Exception::CODE_DocumentoNoInteroperable;
		}
		if ($faultcode == GDE2Exception::MSG_TokenYaUtilizado) {
			return GDE2Exception::CODE_TokenYaUtilizado;
		}
		if ($faultcode == GDE2Exception::MSG_TokenCaducado) {
			return GDE2Exception::CODE_TokenCaducado;
		}
		if ($faultcode == GDE2Exception::MSG_TokenIncorrecto) {
			return GDE2Exception::CODE_TokenIncorrecto;
		}
		if ($faultcode == GDE2Exception::MSG_ExpedienteNoInteroperable) {
			return GDE2Exception::CODE_ExpedienteNoInteroperable;
		}
		if ($faultcode == GDE2Exception::MSG_XMLExpedienteNoValido) {
			return GDE2Exception::CODE_XMLExpedienteNoValido;
		}
		if ($faultcode == GDE2Exception::MSG_DocumentoVacio) {
			return GDE2Exception::CODE_DocumentoVacio;
		}
		if ($faultcode == GDE2Exception::MSG_DocumentoNoExistente) {
			return GDE2Exception::CODE_DocumentoNoExistente;
		}
		if ($faultcode == GDE2Exception::MSG_PathAutoNoDisponible) {
			return GDE2Exception::CODE_PathAutoNoDisponible;
		}

		return GDE2Exception::CODE_Desconocido;
	}


}


?>