<?php
namespace WSCOMUN\REGDEPARTAMENTAL;
use WSCOMUN\WSComunFClient;
use ArrayObject;
use Exception;
use SoapClient;
use SoapVar;

/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Portafirmas
 *
 * @package		WSClientRegDepartamental
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2018 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */
class WSClientRegDepartamental extends WSComunFClient
{

	/**
	 *
	 * Devuelve una instancia del cliente WSSSoapClient debidamente configurado para trabajar contra el servicio actual
	 *
	 * @return	\WSCOMUN\WSSSoapClient	Devuelve el objeto o null si error
	 * @access 	private
	 */
	private function createClient() {
		$opcionesClienteWS = array (
				'soap_version' => SOAP_1_1, //SOAP 1.2
				'user_agent' => 'WSSSoapClient',
				'exceptions' => true,
				'cache_wsdl' => self::$MYSOAPOP_WSDL_CACHE,
				'trace' => self::$MYSOAPOP_TRACE
		);

		$this->disableWSSecurity();
		$this->__clienteOn(self::KEYCLIENTE_REGDEPARTAMENTAL, false, $opcionesClienteWS);
		$clienteWS = $this->__getClient(self::KEYCLIENTE_REGDEPARTAMENTAL);

		return $clienteWS;
	}


	/**
	 *
	 * Crea el tag de de Consulta Histrico que recupera el histrico de un registro departamental, y lo devuelve dentro de un ArrayObject
	 *
	 * @param string $codigoRegistro Cdigo del RD aconsultar
	 * @param string $fechaRegistro Fecha de creacin del registro a consultar (formato "YYYYMMDDHH24MISS")
	 * @param string $fieldName Tag en el que se encapsularan los datos
	 * @param string $ns NS del tag
	 * @return ArrayObject	ArrayObject del nivel del tag, al que se deben aadir los tags restantes
	 * @access 	private
	 */
    private function doConsultaRD($codigoRegistro, $fechaRegistro, $fieldName, $ns) {
        $oAux = new RegistroDepartamentalCodigoType();
		$oAux->setCodigoRegistro($codigoRegistro);
		$oAux->setFechaRegistro($fechaRegistro);
		$regDepWS = $oAux->toSoap($fieldName, $ns);


		$mainWS = new ArrayObject();
		$mainWS->append($regDepWS);
		return $mainWS;
	}


	/**
	 *
	 * Permite recuperar el histrico de un Registro Departamental
	 *
	 * @param string $codigoRegistro Cdigo del RD aconsultar
	 * @param string $fechaRegistro Fecha de creacin del registro a consultar (formato "YYYYMMDDHH24MISS")
	 * @return	array 	Array asociativo con la respuesta del servicio
	 * @access 	public
	 */
	public function consultaHistorico($codigoRegistro, $fechaRegistro)
	{
		try
		{
			// Crea y configura el cliente WSSSoapClient
			/** var $clienteWS WSCOMUN\WSSSoapClient */
			$clienteWS = $this->createClient();

			// Nivel de peticion
			$mainWS = $this->doConsultaRD($codigoRegistro, $fechaRegistro, 'codigoRegistroDepartamental', self::$NAMESPACE_REGDEPARTAMENTAL);

			// Realiza la peticion
			$miSoapRQ = new SoapVar($mainWS, SOAP_ENC_OBJECT,null,null, 'consultaHistorico', self::$NAMESPACE_REGDEPARTAMENTAL);
			$clienteWS->consultaHistorico($miSoapRQ);

			// El cdigo no debera acceder a este punto, se lanza excepcin si se alcanza este codigo
	        throw new Exception('Formato de las respuestas modificado. Debe modificarse el tratamiento de las respuestas del WS (MTOM)');
	    }
		catch (Exception $e)
		{
			// Obtiene el array con la respuesta o lanza excepcion
			$vRetorno = $this->tratarInnerException($clienteWS, $e);

			// Convierte en el objeto apropiado, y lo devuelve
			$oRetorno = consultaHistoricoResponse::fromSoap($vRetorno);
			return $oRetorno;
		}

	}//consultaHistorico


	/**
	 *
	 * Permite recuperar los datos asociados a un Registro Departamental
	 *
	 * @param string $codigoRegistro Cdigo del RD aconsultar
	 * @param string $fechaRegistro Fecha de creacin del registro a consultar (formato "YYYYMMDDHH24MISS")
	 * @param boolean $devolverDocumentos Indica si se deben devolver documentos
	 * @return	array 	Array asociativo con la respuesta del servicio
	 * @access 	public
	 */
	public function consultaRegistroDepartamental($codigoRegistro, $fechaRegistro, $devolverDocumentos)
	{
	    try
	    {
			// Crea y configura el cliente WSSSoapClient
			$clienteWS = $this->createClient();

	        // Nivel de peticion
	        $mainWS = $this->doConsultaRD($codigoRegistro, $fechaRegistro, 'codigoRegistroDepartamental', self::$NAMESPACE_REGDEPARTAMENTAL);
	        $mainWS->append(new SoapVar($devolverDocumentos, XSD_BOOLEAN, null, null,'devolverDocumentos', self::$NAMESPACE_REGDEPARTAMENTAL));

	        // Realiza la peticion
	        $miSoapRQ = new SoapVar($mainWS, SOAP_ENC_OBJECT,null,null, 'consultaRegistroDepartamental', self::$NAMESPACE_REGDEPARTAMENTAL);
	        $clienteWS->consultaRegistroDepartamental($miSoapRQ);

	        // El cdigo no debera acceder a este punto, se lanza excepcin si se alcanza este codigo
	        throw new Exception('Formato de las respuestas modificado. Debe modificarse el tratamiento de las respuestas del WS (MTOM)');
	    }
		catch (Exception $e)
		{
			// Obtiene el array con la respuesta o lanza excepcion
			$vRetorno = $this->tratarInnerException($clienteWS, $e);

			// Convierte en el objeto apropiado, y lo devuelve
			$oRetorno = consultaRegistroDepartamentalResponse::fromSoap($vRetorno);
			return $oRetorno;
		}
	}//consultaRegistroDepartamental


	/**
	 *
	 * Realiza la creacin de un Registro Departamental
	 *
	 * @param string $codigoOrganismoUnidadDepartamental Cdigo del organismo de la unidad departamental
	 * @param string $codigoUnidadDepartamental Cdigo de la unidad departamental
	 * @param string $tipoRegistroDepartamental Indica el tipo de registro E:Entrada S:Salida
	 * @param string $codigoAsuntoHabitual Cdigo de la unidad del asusto habitual
	 * @param string $asunto Descripcin del asunto
	 * @param string $observacionesDepartamentales Observaciones Departamentales
	 * @param string $observacionesGenerales Observaciones Generales
	 * @param string $datosIdentificativos
	 * @param string $destinos
	 * @param string $datosRegistroGeneralSalida Estructura que define el RGS (Registro General de Salida) en el caso en que se sepa
	 * @param string $otraUnidadDeProcedencia Cdigo de otra unidad de procedencia/destino
	 * @param string $descripcionOtraUnidadDeProcedencia Descripcin otra unidad de procedencia/destino en el caso que la Otra Unidad no est codificada en mi departamento,
	 *                                                    indicar solo descripcin. Se crear el RDS con este destino, no se utilizar la Lista de Destinos anterior
	 *
	 * @param string $datosRegistroDepartamentalOrigen Estructura que define los datosdel RDE del que procede el RD que se va a crear
	 * @param string $tipoTransporte Indica el Tipo de transporte
	 * @param string $datosExpediente
	 * @param string $documentos
	 * @return	array 	Array asociativo con la respuesta del servicio
	 * @access 	public
	 */
	public function creacionRegistroDepartamental($codigoOrganismoUnidadDepartamental, $codigoUnidadDepartamental,
							$tipoRegistroDepartamental, $codigoAsuntoHabitual, $asunto, $observacionesDepartamentales,
							$observacionesGenerales, $datosIdentificativos, $destinos, $datosRegistroGeneralSalida,
							$otraUnidadDeProcedencia, $descripcionOtraUnidadDeProcedencia, $datosRegistroDepartamentalOrigen,
							$tipoTransporte, $datosExpediente, $documentos)
	{
	    try
	    {
			// Crea y configura el cliente WSSSoapClient
			$clienteWS = $this->createClient();

	        // Nivel de peticion
	        $newItem = new creacionRegistroDepartamental();

	        $newItem->setCodigoOrganismoUnidadDepartamental($codigoOrganismoUnidadDepartamental);
	        $newItem->setCodigoUnidadDepartamental($codigoUnidadDepartamental);
	        $newItem->setTipoRegistroDepartamental($tipoRegistroDepartamental);
	        if (isset($codigoAsuntoHabitual)) {
	            $newItem->setCodigoAsuntoHabitual($codigoAsuntoHabitual);
	        }
	        $newItem->setAsunto($asunto);
	        if (isset($observacionesDepartamentales)) {
	            $newItem->setObservacionesDepartamentales($observacionesDepartamentales);
	        }
	        if (isset($observacionesGenerales)) {
	            $newItem->setObservacionesGenerales($observacionesGenerales);
	        }
	        $newItem->setDatosIdentificativos($datosIdentificativos);
	        if (isset($destinos)) {
	            $newItem->setDestinos($destinos);
	        }
	        if (isset($datosRegistroGeneralSalida)) {
	            $newItem->setDatosRegistroGeneralSalida($datosRegistroGeneralSalida);
	        }
	        if (isset($otraUnidadDeProcedencia)) {
	            $newItem->setOtraUnidadDeProcedencia($otraUnidadDeProcedencia);
	        }
	        if (isset($descripcionOtraUnidadDeProcedencia)) {
	            $newItem->setDescripcionOtraUnidadDeProcedencia($descripcionOtraUnidadDeProcedencia);
	        }
	        if (isset($datosRegistroDepartamentalOrigen)) {
	            $newItem->setDatosRegistroDepartamentalOrigen($datosRegistroDepartamentalOrigen);
	        }
	        if (isset($tipoTransporte)) {
	            $newItem->setTipoTransporte($tipoTransporte);
	        }
	        if (isset($datosExpediente)) {
	            $newItem->setDatosExpediente($datosExpediente);
	        }
	        if (isset($documentos)) {
	            $newItem->setDocumentos($documentos);
	        }

	        // Realiza la peticion
	        $miSoapRQ = $newItem->toSoap('creacionRegistroDepartamental', self::$NAMESPACE_REGDEPARTAMENTAL);
	        $clienteWS->creacionRegistroDepartamental($miSoapRQ);

	    	// El cdigo no debera acceder a este punto, se lanza excepcin si se alcanza este codigo
	        throw new Exception('Formato de las respuestas modificado. Debe modificarse el tratamiento de las respuestas del WS (MTOM)');
	    }
		catch (Exception $e)
		{
			// Obtiene el array con la respuesta o lanza excepcion
			$vRetorno = $this->tratarInnerException($clienteWS, $e);

			// Convierte en el objeto apropiado, y lo devuelve
			$oRetorno = creacionRegistroDepartamentalResponse::fromSoap($vRetorno);
			return $oRetorno;
		}
	}//consultaRegistroDepartamental


	/**
	 * Tratamiento estandarizado de las excepciones producidas en la invocacion al WS
	 *
	 * @param SoapClient	$clienteWS clienteWS utilizado en la peticion al Servicio Web
	 * @param Exception	$e Excepcion producida
	 * @return	array 	Array asociativo que contiene la respuesta del servicio
	 */
	private function tratarInnerException($clienteWS, $e)
	{
		// Comprobamos si estamos ante excepcion MTOM
		$mensaje = $e->getMessage();
		$mensaje = trim(strtolower($mensaje));
		switch ($mensaje)
		{
			case 'looks like we got no xml document' :
				// Obtiene la respuesta
				$response = $clienteWS->__getLastResponse();
				$vRetorno = $this->tratarMTOMEstandar($response);
				return $vRetorno;
			break;

			default:
				$this->tratarExcepcionEstandar($e, $clienteWS);
			break;
		}
	}//tratarInnerException
}

?>